@@ -31,11 +31,11 @@ class Drawer:
         )
 
     def make_color(self, length_range, length):
-        has_special = (
-            self.poster.special_number.get("special_number2", length)
-            < length
-            < self.poster.special_number.get("special_number1", length)
-        )
+        sp2 = self.poster.special_number.get("special_number2")
+        sp1 = self.poster.special_number.get("special_number1")
+        has_special = False
+        if sp2 and sp1 and length:
+            has_special = sp2 < length < sp1
         color_from = (
             self.poster.colors["special"]
             if has_special
@@ -116,7 +116,7 @@ class Drawer:
             dom_tuple = DOM_BOX_DICT.get(types_len).get("dom")
             index = 0
             for _type in self.poster.type_list:
-                num = day_tracks.get(_type)
+                num = day_tracks.get(_type, 0)
                 length_range = self.poster.length_range_by_date_dict.get(_type, 1)
                 if not num:
                     continue
